package pps.core.task.job;

import cn.hutool.core.util.ObjectUtil;
import pps.cloud.space.service.IDailyElectricityTrendCloudService;
import pps.core.common.cache.TaskLockCache;
import pps.core.task.constant.TaskConstant;
import xstartup.annotation.XService;
import xstartup.annotation.XText;
import xstartup.base.XContext;
import xstartup.data.XServiceResult;
import xstartup.service.job.XJob;
import xstartup.service.job.annotation.XCronTrigger;

/**
 * 日用电趋势定时任务
 *
 * @author ZWT
 * @date 2024/05/22 17:12
 */
@XText("日用电趋势定时任务")
@XService
public class DailyElectricityTrendJob implements XJob {

    /**
     * 每天0点02执行(跑前一天数据)
     *
     * @param xContext x上下文
     * @return {@link XServiceResult}
     */
    @XCronTrigger(value = TaskConstant.EVERY_DAY_2)
    @Override
    public XServiceResult execute(XContext xContext) {
        xContext.getLogger().info("------ DailyElectricityTrendJob start:{}", System.currentTimeMillis());
        String key = TaskConstant.TASK_LOCK_KEY + "DailyElectricityTrendJob";
        TaskLockCache exist = TaskLockCache.exist(xContext, key);
        if (ObjectUtil.isNull(exist)) {
            TaskLockCache cache = new TaskLockCache();
            cache.setRedisKey(key);
            cache.setRedisValue(key);
            TaskLockCache.set(xContext, cache);
            try {
                IDailyElectricityTrendCloudService service = xContext.getBean(IDailyElectricityTrendCloudService.class);
                XServiceResult result = service.dailyElectricityTrendJob(xContext);
                result.throwIfFail();
            } catch (Exception e) {
                xContext.getLogger().error("------ DailyElectricityTrendJob Exception: ", e);
            } finally {
                xContext.getLogger().info("------ DailyElectricityTrendJob end:{}", System.currentTimeMillis());
                TaskLockCache.delete(xContext, key);
            }
        }
        return XServiceResult.OK;
    }
}
